%% 1 - INITIALIZE UQLAB

clearvars
rng(100,'twister')
uqlab

%% 
% The forward model computes the deflection of the beam $V$
% at mid-span location, which reads:
%
% $$ V = \frac{ 5 p L^4 }{32 E b h^3}$$
%
% This computation is carried out by the function
% |uq_SimplySupportedBeam(X)| supplied with UQLab.
% The input variables of this function are gathered into the $N \times M$
% matrix |X|, where $N$ and $M$ are the number of realizations
% input variables, respectively.
% The variables are given in the following order:
%
% # $b$: beam width $(m)$
% # $h$: beam height $(m)$
% # $L$: beam length $(m)$
% # $E$: Young's modulus $(Pa)$
% # $p$: uniform load $(N/m)$

%%

% Load the high fidelity data
high_data = load('high_fidelity_data_2.mat');
XH = high_data.X_high;
YH = high_data.y_high;

% Load the low fidelity data
low_data = load('low_fidelity_data_2.mat');
XL = low_data.X_low;
YL = low_data.y_low;

%% 2 - FORWARD MODEL
gpModel = fitrgp(XL, YL','Standardize', true);
% Save the trained GP model to a .mat file
save('trained_gp_model.mat', 'gpModel');
ModelOpts1.Name = 'Beam mid-span deflection1';
ModelOpts1.mFile = 'tpredict_gp';
myForwardModel = uq_createModel(ModelOpts1);

%% 3 - PRIOR DISTRIBUTION OF THE MODEL PARAMETERS

% Specify these distributions as a UQLab INPUT object:
PriorOpts.Marginals(1).Name = 'b';               % beam width 
PriorOpts.Marginals(1).Type = 'Constant';
PriorOpts.Marginals(1).Parameters = XH(1);%[0.15]   % (m)

PriorOpts.Marginals(2).Name = 'h';               % beam height 
PriorOpts.Marginals(2).Type = 'Constant';
PriorOpts.Marginals(2).Parameters = XH(2);%[0.3];       % (m)

PriorOpts.Marginals(3).Name = 'L';               % beam length 
PriorOpts.Marginals(3).Type = 'Constant';
PriorOpts.Marginals(3).Parameters = XH(3);%5;           % (m)

PriorOpts.Marginals(4).Name = 'E';               % Young's modulus
PriorOpts.Marginals(4).Type = 'LogNormal';
PriorOpts.Marginals(4).Moments = [35 4.5]*1e9;   % (N/m^2)

PriorOpts.Marginals(5).Name = 'p';               % uniform load 
PriorOpts.Marginals(5).Type = 'Gaussian';
PriorOpts.Marginals(5).Moments = [10000 1000]; % (N/m)

myPriorDist = uq_createInput(PriorOpts);


%% 4 - MEASUREMENT DATA

myData.y = [YH]; % (m)
myData.Name = 'Mid-span deflection';

%% 5 - DISCREPANCY MODEL
%
% By default, the Bayesian calibration module of UQLab assumes
% an independent and identically distributed
% discrepancy $\varepsilon\sim\mathcal{N}(0,\sigma^2)$ between
% the observations and the predictions for each data.
% The variance $\sigma^2$ of the discrepancy term is by default
% given a uniform prior distribution:

%% 6 - BAYESIAN ANALYSIS
%
% The options of the Bayesian analysis are specified with the following
% structure:
BayesOpts.Type = 'Inversion';
BayesOpts.Data = myData;

%%
% Run the Bayesian inversion analysis:
myBayesianAnalysis = uq_createAnalysis(BayesOpts);
%%
% Print out a report of the results:
uq_print(myBayesianAnalysis)

%%
% Create a graphical representation of the results:
uq_display(myBayesianAnalysis)